// Copyright (c) 2022 NetEase, Inc. All rights reserved.
// Use of this source code is governed by a MIT license that can be
// found in the LICENSE file.

///
/// 房间音频dump文件类型
///
enum NEAudioDumpType {
  kPCM,
  kAll,
  kWAV,
}

///
/// 本地音频输出设备
///
enum NEAudioOutputDevice {
  ///
  /// 扬声器
  ///
  kSpeakerPhone,

  ///
  /// 有线耳机
  ///
  kWiredHeadset,

  ///
  /// 听筒
  ///
  kEarpiece,

  ///
  /// 蓝牙耳机
  ///
  kBluetoothHeadset,
}

extension NEAudioOutputDeviceTypeExtension on NEAudioOutputDevice {
  static NEAudioOutputDevice fromType(int type) {
    return NEAudioOutputDevice.values.firstWhere(
      (element) => element.index == type,
      orElse: () => NEAudioOutputDevice.kEarpiece,
    );
  }
}

class NECreateAudioMixingOption {
  String path;
  int loopCount;
  bool sendEnabled;
  bool playbackEnabled;
  int sendVolume;
  int playbackVolume;

  NECreateAudioMixingOption({
    required this.path,
    this.loopCount = 0,
    this.sendEnabled = true,
    this.playbackEnabled = true,
    this.sendVolume = 100,
    this.playbackVolume = 100,
  });
}

class NECreateAudioEffectOption {
  String path;
  int loopCount;
  bool sendEnabled;
  bool playbackEnabled;
  int sendVolume;
  int playbackVolume;

  NECreateAudioEffectOption({
    required this.path,
    this.loopCount = 0,
    this.sendEnabled = true,
    this.playbackEnabled = true,
    this.sendVolume = 100,
    this.playbackVolume = 100,
  });
}

enum NERoomBeautyEffectType {
  /// -1
  kUnknownType,
  kWhiteTeeth,
  kLightEye,
  kWhiten,
  kSmooth,
  kSmallNose,
  kEyeDis,
  kEyeAngle,
  kMouth,
  kBigEye,
  kSmallFace,
  kJaw,
  kThinFace,
  kFaceRuddy,
  kLongNose,
  kPhiltrum,
  kMouthAngle,
  kRoundEye,
  kEyeCorner,
  kVFace,
  kUnderJaw,
  kNarrowFace,
  kCheekBone,
  kFaceSharpen,
}

///
/// 订阅视频流类型
///
enum NEVideoStreamType {
  ///
  /// 大流
  ///
  kHigh,

  ///
  /// 小流
  ///
  kLow
}

extension NERoomBeautyEffectTypeExtension on NERoomBeautyEffectType {
  static int fromType(NERoomBeautyEffectType beautyType) =>
      (NERoomBeautyEffectType.values
          .firstWhere(
            (element) => element == beautyType,
            orElse: () => NERoomBeautyEffectType.kUnknownType,
          )
          .index);
}

class NERoomVirtualBackgroundType {
  static const kBackgroundColor = 1;
  static const kBackgroundImg = 2;
  static const kBackgroundBlur = 3;

  static const kBlurDegreeLow = 1;
  static const kBlurDegreeMedium = 2;
  static const kBlurDegreeHigh = 3;
}
